@@ -1,6 +1,7 @@
 def get_chunks(s, chunk_size, text_id):
     """
-    Function to split a text, inspired by https://stackoverflow.com/questions/57023348/python-splitting-a-long-text-into-chunks-of-strings-given-character-limit/57023373
+    Function to split a text, inspired by\
+        https://stackoverflow.com/questions/57023348/python-splitting-a-long-text-into-chunks-of-strings-given-character-limit/57023373
 
     :param s: The text to chunk
     :type s: str
@@ -11,7 +12,8 @@ def get_chunks(s, chunk_size, text_id):
     :param text_id: Some identifier of the text, e.g the text's file name
     :type text_id: str
 
-    :return: yields dicts like `{"id": "example_text.txt", "chunk_nr": "001", "text": "text of chunk", "char_count": 13}`
+    :return: yields dicts like\
+        `{"id": "example_text.txt", "chunk_nr": "001", "text": "text of chunk", "char_count": 13}`
     :rtype: dict
     """
     start = 0
@@ -27,10 +29,10 @@ def get_chunks(s, chunk_size, text_id):
             "char_count": len(text)
         }
         counter += 1
-        start = end +1
+        start = end + 1
     yield {
-            "id": f"{counter:03}___{text_id}",
-            "chunk_nr": f"{counter:03}",
-            "text": s[start:].replace('\n', ''),
-            "char_count": len(s[start:])
-            }
+        "id": f"{counter:03}___{text_id}",
+        "chunk_nr": f"{counter:03}",
+        "text": s[start:].replace('\n', ''),
+        "char_count": len(s[start:])
+    }
